exceptiontools
==============

.. automodule:: abjad.tools.exceptiontools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.exceptiontools.AssignabilityError.AssignabilityError
      ~abjad.tools.exceptiontools.ExtraSpannerError.ExtraSpannerError
      ~abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError
      ~abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError
      ~abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError
      ~abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError
      ~abjad.tools.exceptiontools.MissingTempoError.MissingTempoError
      ~abjad.tools.exceptiontools.OverfullContainerError.OverfullContainerError
      ~abjad.tools.exceptiontools.PartitionError.PartitionError
      ~abjad.tools.exceptiontools.SchemeParserFinishedError.SchemeParserFinishedError
      ~abjad.tools.exceptiontools.UnboundedTimeIntervalError.UnboundedTimeIntervalError
      ~abjad.tools.exceptiontools.UnderfullContainerError.UnderfullContainerError
